/*!
 * Bootstrap v4.4.1 (https://getbootstrap.com/)
 * Copyright 2011-2019 The Bootstrap Authors
 * Copyright 2011-2019 Twitter, Inc.
 * Licensed under MIT (https://github.com/twbs/bootstrap/blob/master/LICENSE)
 */
.btn {
    display:inline-block;
    font-weight:400;
    color:#212529;
    text-align:center;
    vertical-align:middle;
    cursor:pointer;
    -webkit-user-select:none;
    -moz-user-select:none;
    -ms-user-select:none;
    user-select:none;
    background-color:transparent;
    border:1px solid transparent;
    padding:.375rem .75rem;
    font-size:1rem;
    line-height:1.5;
    border-radius:.25rem;
    transition:color .15s ease-in-out,background-color .15s ease-in-out,border-color .15s ease-in-out,box-shadow .15s ease-in-out
   }
   @media (prefers-reduced-motion:reduce) {
    .btn {
     transition:none
    }
   }
   .btn:visited {
       color: unset;
   }
   .btn:hover {
    color:#212529;
    text-decoration:none
   }
   .btn.focus,
   .btn:focus {
    outline:0;
    box-shadow:0 0 0 .2rem rgba(0,123,255,.25)
   }
   .btn.disabled,
   .btn:disabled {
    opacity:.65
   }
   a.btn.disabled,
   fieldset:disabled a.btn {
    pointer-events:none
   }
   .btn-primary {
    color:#fff;
    background-color:#007bff;
    border-color:#007bff
   }
   .btn-primary:hover {
    color:#fff;
    background-color:#0069d9;
    border-color:#0062cc
   }
   .btn-primary.focus,
   .btn-primary:focus {
    color:#fff;
    background-color:#0069d9;
    border-color:#0062cc;
    box-shadow:0 0 0 .2rem rgba(38,143,255,.5)
   }
   .btn-primary.disabled,
   .btn-primary:disabled {
    color:#fff;
    background-color:#007bff;
    border-color:#007bff
   }
   .btn-primary:not(:disabled):not(.disabled).active,
   .btn-primary:not(:disabled):not(.disabled):active,
   .show>.btn-primary.dropdown-toggle {
    color:#fff;
    background-color:#0062cc;
    border-color:#005cbf
   }
   .btn-primary:not(:disabled):not(.disabled).active:focus,
   .btn-primary:not(:disabled):not(.disabled):active:focus,
   .show>.btn-primary.dropdown-toggle:focus {
    box-shadow:0 0 0 .2rem rgba(38,143,255,.5)
   }
   .btn-secondary {
    color:#fff;
    background-color:#6c757d;
    border-color:#6c757d
   }
   .btn-secondary:hover {
    color:#fff;
    background-color:#5a6268;
    border-color:#545b62
   }
   .btn-secondary.focus,
   .btn-secondary:focus {
    color:#fff;
    background-color:#5a6268;
    border-color:#545b62;
    box-shadow:0 0 0 .2rem rgba(130,138,145,.5)
   }
   .btn-secondary.disabled,
   .btn-secondary:disabled {
    color:#fff;
    background-color:#6c757d;
    border-color:#6c757d
   }
   .btn-secondary:not(:disabled):not(.disabled).active,
   .btn-secondary:not(:disabled):not(.disabled):active,
   .show>.btn-secondary.dropdown-toggle {
    color:#fff;
    background-color:#545b62;
    border-color:#4e555b
   }
   .btn-secondary:not(:disabled):not(.disabled).active:focus,
   .btn-secondary:not(:disabled):not(.disabled):active:focus,
   .show>.btn-secondary.dropdown-toggle:focus {
    box-shadow:0 0 0 .2rem rgba(130,138,145,.5)
   }
   .btn-success {
    color:#fff;
    background-color:#28a745;
    border-color:#28a745
   }
   .btn-success:hover {
    color:#fff;
    background-color:#218838;
    border-color:#1e7e34
   }
   .btn-success.focus,
   .btn-success:focus {
    color:#fff;
    background-color:#218838;
    border-color:#1e7e34;
    box-shadow:0 0 0 .2rem rgba(72,180,97,.5)
   }
   .btn-success.disabled,
   .btn-success:disabled {
    color:#fff;
    background-color:#28a745;
    border-color:#28a745
   }
   .btn-success:not(:disabled):not(.disabled).active,
   .btn-success:not(:disabled):not(.disabled):active,
   .show>.btn-success.dropdown-toggle {
    color:#fff;
    background-color:#1e7e34;
    border-color:#1c7430
   }
   .btn-success:not(:disabled):not(.disabled).active:focus,
   .btn-success:not(:disabled):not(.disabled):active:focus,
   .show>.btn-success.dropdown-toggle:focus {
    box-shadow:0 0 0 .2rem rgba(72,180,97,.5)
   }
   .btn-info {
    color:#fff;
    background-color:#17a2b8;
    border-color:#17a2b8
   }
   .btn-info:hover {
    color:#fff;
    background-color:#138496;
    border-color:#117a8b
   }
   .btn-info.focus,
   .btn-info:focus {
    color:#fff;
    background-color:#138496;
    border-color:#117a8b;
    box-shadow:0 0 0 .2rem rgba(58,176,195,.5)
   }
   .btn-info.disabled,
   .btn-info:disabled {
    color:#fff;
    background-color:#17a2b8;
    border-color:#17a2b8
   }
   .btn-info:not(:disabled):not(.disabled).active,
   .btn-info:not(:disabled):not(.disabled):active,
   .show>.btn-info.dropdown-toggle {
    color:#fff;
    background-color:#117a8b;
    border-color:#10707f
   }
   .btn-info:not(:disabled):not(.disabled).active:focus,
   .btn-info:not(:disabled):not(.disabled):active:focus,
   .show>.btn-info.dropdown-toggle:focus {
    box-shadow:0 0 0 .2rem rgba(58,176,195,.5)
   }
   .btn-warning {
    color:#212529;
    background-color:#ffc107;
    border-color:#ffc107
   }
   .btn-warning:hover {
    color:#212529;
    background-color:#e0a800;
    border-color:#d39e00
   }
   .btn-warning.focus,
   .btn-warning:focus {
    color:#212529;
    background-color:#e0a800;
    border-color:#d39e00;
    box-shadow:0 0 0 .2rem rgba(222,170,12,.5)
   }
   .btn-warning.disabled,
   .btn-warning:disabled {
    color:#212529;
    background-color:#ffc107;
    border-color:#ffc107
   }
   .btn-warning:not(:disabled):not(.disabled).active,
   .btn-warning:not(:disabled):not(.disabled):active,
   .show>.btn-warning.dropdown-toggle {
    color:#212529;
    background-color:#d39e00;
    border-color:#c69500
   }
   .btn-warning:not(:disabled):not(.disabled).active:focus,
   .btn-warning:not(:disabled):not(.disabled):active:focus,
   .show>.btn-warning.dropdown-toggle:focus {
    box-shadow:0 0 0 .2rem rgba(222,170,12,.5)
   }
   .btn-danger {
    color:#fff;
    background-color:#dc3545;
    border-color:#dc3545
   }
   .btn-danger:hover {
    color:#fff;
    background-color:#c82333;
    border-color:#bd2130
   }
   .btn-danger.focus,
   .btn-danger:focus {
    color:#fff;
    background-color:#c82333;
    border-color:#bd2130;
    box-shadow:0 0 0 .2rem rgba(225,83,97,.5)
   }
   .btn-danger.disabled,
   .btn-danger:disabled {
    color:#fff;
    background-color:#dc3545;
    border-color:#dc3545
   }
   .btn-danger:not(:disabled):not(.disabled).active,
   .btn-danger:not(:disabled):not(.disabled):active,
   .show>.btn-danger.dropdown-toggle {
    color:#fff;
    background-color:#bd2130;
    border-color:#b21f2d
   }
   .btn-danger:not(:disabled):not(.disabled).active:focus,
   .btn-danger:not(:disabled):not(.disabled):active:focus,
   .show>.btn-danger.dropdown-toggle:focus {
    box-shadow:0 0 0 .2rem rgba(225,83,97,.5)
   }
   .btn-light {
    color:#212529;
    background-color:#f8f9fa;
    border-color:#f8f9fa
   }
   .btn-light:hover {
    color:#212529;
    background-color:#e2e6ea;
    border-color:#dae0e5
   }
   .btn-light.focus,
   .btn-light:focus {
    color:#212529;
    background-color:#e2e6ea;
    border-color:#dae0e5;
    box-shadow:0 0 0 .2rem rgba(216,217,219,.5)
   }
   .btn-light.disabled,
   .btn-light:disabled {
    color:#212529;
    background-color:#f8f9fa;
    border-color:#f8f9fa
   }
   .btn-light:not(:disabled):not(.disabled).active,
   .btn-light:not(:disabled):not(.disabled):active,
   .show>.btn-light.dropdown-toggle {
    color:#212529;
    background-color:#dae0e5;
    border-color:#d3d9df
   }
   .btn-light:not(:disabled):not(.disabled).active:focus,
   .btn-light:not(:disabled):not(.disabled):active:focus,
   .show>.btn-light.dropdown-toggle:focus {
    box-shadow:0 0 0 .2rem rgba(216,217,219,.5)
   }
   .btn-dark {
    color:#fff;
    background-color:#343a40;
    border-color:#343a40
   }
   .btn-dark:hover {
    color:#fff;
    background-color:#23272b;
    border-color:#1d2124
   }
   .btn-dark.focus,
   .btn-dark:focus {
    color:#fff;
    background-color:#23272b;
    border-color:#1d2124;
    box-shadow:0 0 0 .2rem rgba(82,88,93,.5)
   }
   .btn-dark.disabled,
   .btn-dark:disabled {
    color:#fff;
    background-color:#343a40;
    border-color:#343a40
   }
   .btn-dark:not(:disabled):not(.disabled).active,
   .btn-dark:not(:disabled):not(.disabled):active,
   .show>.btn-dark.dropdown-toggle {
    color:#fff;
    background-color:#1d2124;
    border-color:#171a1d
   }
   .btn-dark:not(:disabled):not(.disabled).active:focus,
   .btn-dark:not(:disabled):not(.disabled):active:focus,
   .show>.btn-dark.dropdown-toggle:focus {
    box-shadow:0 0 0 .2rem rgba(82,88,93,.5)
   }
   .btn-outline-primary {
    color:#007bff;
    border-color:#007bff
   }
   .btn-outline-primary:hover {
    color:#fff;
    background-color:#007bff;
    border-color:#007bff
   }
   .btn-outline-primary.focus,
   .btn-outline-primary:focus {
    box-shadow:0 0 0 .2rem rgba(0,123,255,.5)
   }
   .btn-outline-primary.disabled,
   .btn-outline-primary:disabled {
    color:#007bff;
    background-color:transparent
   }
   .btn-outline-primary:not(:disabled):not(.disabled).active,
   .btn-outline-primary:not(:disabled):not(.disabled):active,
   .show>.btn-outline-primary.dropdown-toggle {
    color:#fff;
    background-color:#007bff;
    border-color:#007bff
   }
   .btn-outline-primary:not(:disabled):not(.disabled).active:focus,
   .btn-outline-primary:not(:disabled):not(.disabled):active:focus,
   .show>.btn-outline-primary.dropdown-toggle:focus {
    box-shadow:0 0 0 .2rem rgba(0,123,255,.5)
   }
   .btn-outline-secondary {
    color:#6c757d;
    border-color:#6c757d
   }
   .btn-outline-secondary:hover {
    color:#fff;
    background-color:#6c757d;
    border-color:#6c757d
   }
   .btn-outline-secondary.focus,
   .btn-outline-secondary:focus {
    box-shadow:0 0 0 .2rem rgba(108,117,125,.5)
   }
   .btn-outline-secondary.disabled,
   .btn-outline-secondary:disabled {
    color:#6c757d;
    background-color:transparent
   }
   .btn-outline-secondary:not(:disabled):not(.disabled).active,
   .btn-outline-secondary:not(:disabled):not(.disabled):active,
   .show>.btn-outline-secondary.dropdown-toggle {
    color:#fff;
    background-color:#6c757d;
    border-color:#6c757d
   }
   .btn-outline-secondary:not(:disabled):not(.disabled).active:focus,
   .btn-outline-secondary:not(:disabled):not(.disabled):active:focus,
   .show>.btn-outline-secondary.dropdown-toggle:focus {
    box-shadow:0 0 0 .2rem rgba(108,117,125,.5)
   }
   .btn-outline-success {
    color:#28a745;
    border-color:#28a745
   }
   .btn-outline-success:hover {
    color:#fff;
    background-color:#28a745;
    border-color:#28a745
   }
   .btn-outline-success.focus,
   .btn-outline-success:focus {
    box-shadow:0 0 0 .2rem rgba(40,167,69,.5)
   }
   .btn-outline-success.disabled,
   .btn-outline-success:disabled {
    color:#28a745;
    background-color:transparent
   }
   .btn-outline-success:not(:disabled):not(.disabled).active,
   .btn-outline-success:not(:disabled):not(.disabled):active,
   .show>.btn-outline-success.dropdown-toggle {
    color:#fff;
    background-color:#28a745;
    border-color:#28a745
   }
   .btn-outline-success:not(:disabled):not(.disabled).active:focus,
   .btn-outline-success:not(:disabled):not(.disabled):active:focus,
   .show>.btn-outline-success.dropdown-toggle:focus {
    box-shadow:0 0 0 .2rem rgba(40,167,69,.5)
   }
   .btn-outline-info {
    color:#17a2b8;
    border-color:#17a2b8
   }
   .btn-outline-info:hover {
    color:#fff;
    background-color:#17a2b8;
    border-color:#17a2b8
   }
   .btn-outline-info.focus,
   .btn-outline-info:focus {
    box-shadow:0 0 0 .2rem rgba(23,162,184,.5)
   }
   .btn-outline-info.disabled,
   .btn-outline-info:disabled {
    color:#17a2b8;
    background-color:transparent
   }
   .btn-outline-info:not(:disabled):not(.disabled).active,
   .btn-outline-info:not(:disabled):not(.disabled):active,
   .show>.btn-outline-info.dropdown-toggle {
    color:#fff;
    background-color:#17a2b8;
    border-color:#17a2b8
   }
   .btn-outline-info:not(:disabled):not(.disabled).active:focus,
   .btn-outline-info:not(:disabled):not(.disabled):active:focus,
   .show>.btn-outline-info.dropdown-toggle:focus {
    box-shadow:0 0 0 .2rem rgba(23,162,184,.5)
   }
   .btn-outline-warning {
    color:#ffc107;
    border-color:#ffc107
   }
   .btn-outline-warning:hover {
    color:#212529;
    background-color:#ffc107;
    border-color:#ffc107
   }
   .btn-outline-warning.focus,
   .btn-outline-warning:focus {
    box-shadow:0 0 0 .2rem rgba(255,193,7,.5)
   }
   .btn-outline-warning.disabled,
   .btn-outline-warning:disabled {
    color:#ffc107;
    background-color:transparent
   }
   .btn-outline-warning:not(:disabled):not(.disabled).active,
   .btn-outline-warning:not(:disabled):not(.disabled):active,
   .show>.btn-outline-warning.dropdown-toggle {
    color:#212529;
    background-color:#ffc107;
    border-color:#ffc107
   }
   .btn-outline-warning:not(:disabled):not(.disabled).active:focus,
   .btn-outline-warning:not(:disabled):not(.disabled):active:focus,
   .show>.btn-outline-warning.dropdown-toggle:focus {
    box-shadow:0 0 0 .2rem rgba(255,193,7,.5)
   }
   .btn-outline-danger {
    color:#dc3545;
    border-color:#dc3545
   }
   .btn-outline-danger:hover {
    color:#fff;
    background-color:#dc3545;
    border-color:#dc3545
   }
   .btn-outline-danger.focus,
   .btn-outline-danger:focus {
    box-shadow:0 0 0 .2rem rgba(220,53,69,.5)
   }
   .btn-outline-danger.disabled,
   .btn-outline-danger:disabled {
    color:#dc3545;
    background-color:transparent
   }
   .btn-outline-danger:not(:disabled):not(.disabled).active,
   .btn-outline-danger:not(:disabled):not(.disabled):active,
   .show>.btn-outline-danger.dropdown-toggle {
    color:#fff;
    background-color:#dc3545;
    border-color:#dc3545
   }
   .btn-outline-danger:not(:disabled):not(.disabled).active:focus,
   .btn-outline-danger:not(:disabled):not(.disabled):active:focus,
   .show>.btn-outline-danger.dropdown-toggle:focus {
    box-shadow:0 0 0 .2rem rgba(220,53,69,.5)
   }
   .btn-outline-light {
    color:#f8f9fa;
    border-color:#f8f9fa
   }
   .btn-outline-light:hover {
    color:#212529;
    background-color:#f8f9fa;
    border-color:#f8f9fa
   }
   .btn-outline-light.focus,
   .btn-outline-light:focus {
    box-shadow:0 0 0 .2rem rgba(248,249,250,.5)
   }
   .btn-outline-light.disabled,
   .btn-outline-light:disabled {
    color:#f8f9fa;
    background-color:transparent
   }
   .btn-outline-light:not(:disabled):not(.disabled).active,
   .btn-outline-light:not(:disabled):not(.disabled):active,
   .show>.btn-outline-light.dropdown-toggle {
    color:#212529;
    background-color:#f8f9fa;
    border-color:#f8f9fa
   }
   .btn-outline-light:not(:disabled):not(.disabled).active:focus,
   .btn-outline-light:not(:disabled):not(.disabled):active:focus,
   .show>.btn-outline-light.dropdown-toggle:focus {
    box-shadow:0 0 0 .2rem rgba(248,249,250,.5)
   }
   .btn-outline-dark {
    color:#343a40;
    border-color:#343a40
   }
   .btn-outline-dark:hover {
    color:#fff;
    background-color:#343a40;
    border-color:#343a40
   }
   .btn-outline-dark.focus,
   .btn-outline-dark:focus {
    box-shadow:0 0 0 .2rem rgba(52,58,64,.5)
   }
   .btn-outline-dark.disabled,
   .btn-outline-dark:disabled {
    color:#343a40;
    background-color:transparent
   }
   .btn-outline-dark:not(:disabled):not(.disabled).active,
   .btn-outline-dark:not(:disabled):not(.disabled):active,
   .show>.btn-outline-dark.dropdown-toggle {
    color:#fff;
    background-color:#343a40;
    border-color:#343a40
   }
   .btn-outline-dark:not(:disabled):not(.disabled).active:focus,
   .btn-outline-dark:not(:disabled):not(.disabled):active:focus,
   .show>.btn-outline-dark.dropdown-toggle:focus {
    box-shadow:0 0 0 .2rem rgba(52,58,64,.5)
   }
   .btn-link {
    font-weight:400;
    color:#007bff;
    text-decoration:none
   }
   .btn-link:hover {
    color:#0056b3;
    text-decoration:underline
   }
   .btn-link.focus,
   .btn-link:focus {
    text-decoration:underline;
    box-shadow:none
   }
   .btn-link.disabled,
   .btn-link:disabled {
    color:#6c757d;
    pointer-events:none
   }
   .btn-group-lg>.btn,
   .btn-lg {
    padding:.5rem 1rem;
    font-size:1.25rem;
    line-height:1.5;
    border-radius:.3rem
   }
   .btn-group-sm>.btn,
   .btn-sm {
    padding:.25rem .5rem;
    font-size:.875rem;
    line-height:1.5;
    border-radius:.2rem
   }
   .btn-block {
    display:block;
    width:100%
   }
   .btn-block+.btn-block {
    margin-top:.5rem
   }
   input[type=button].btn-block,
   input[type=reset].btn-block,
   input[type=submit].btn-block {
    width:100%
   }
   .stretched-link::after {
    position:absolute;
    top:0;
    right:0;
    bottom:0;
    left:0;
    z-index:1;
    pointer-events:auto;
    content:"";
    background-color:rgba(0,0,0,0)
   }
